@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2008 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2001-2010 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,25 +38,31 @@ static const char* VANDALE_SERVER = "www.vandale.nl";
 static const char* VANDALE_PORT   = "80";
 
 /*
- * http stuff; the HTTP_REQUEST / HTTP_REQUEST_PROXY have _2_
- * %s fields (for the search term)
+ * http stuff; the HTTP_REQUEST / HTTP_REQUEST_PROXY has _1_
+ * %s field (for the search term)
  */
 #define HTTP_HEADERS \
-"Host: www.vandale.nl\r\n" \
-"User-Agent:  GNUVD/" VERSION "\r\n" \
-"Accept: text/xml,application/xml,application/xhtml+xml,text/html;" \
-"q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;" \
-"q=0.2,text/css,*/*;q=0.1\r\n" \
-"Accept-Language: nl, en\r\n" \
-"Accept-Charset: UTF-8\r\n" \
-"Referer: http://www.vandale.nl/vandale/opzoeken/woordenboek/?zoekwoord=%s\r\n" \
-"\r\n"
+	"Host: www.vandale.nl\r\n"   \
+	"User-Agent:  GNUVD/" VERSION "\r\n"			    \
+	"Accept: text/xml,application/xml,application/xhtml+xml,text/html;" \
+	"q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;" \
+	"q=0.2,text/css,*/*;q=0.1\r\n"					\
+	"Accept-Language: nl, en\r\n"					\
+	"Accept-Charset: UTF-8\r\n"					\
+	"Cookie: country=nl; JSESSIONID=abcifu5Wp8xn5ddIaRULs;"		\
+	" __utmz=183311777.1277462057.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none);" \
+	" __utma=183311777.972421452.1277462057.1277462057.1277462057.1; __utmc=183311777;" \
+	" __utmb=183311777.5.10.1277462057\r\n"				\
+	"Referer: http://www.vandale.nl/vandale/opzoeken/woordenboek/\r\n" \
+	"\r\n"
 
-#define HTTP_REQUEST \
-"GET /vandale/opzoeken/woordenboek/?zoekwoord=%s HTTP/1.0\r\n" HTTP_HEADERS
+#define HTTP_REQUEST							\
+	"GET /vandale/zoekService.do?selectedDictionary=nn&"		\
+	"selectedDictionaryName=Nederlands&searchQuery=%s HTTP/1.1\r\n" HTTP_HEADERS
 
 #define HTTP_REQUEST_PROXY \
-"GET http://www.vandale.nl/vandale/opzoeken/woordenboek/?zoekwoord=%s HTTP/1.0\r\n" HTTP_HEADERS
+	"GET http://www.vandale.nl/vandale/zoekService.do?selectedDictionary=nn&" \
+	"selectedDictionaryName=Nederlands&searchQuery=%s HTTP/1.1\r\n" HTTP_HEADERS
 
 static char* HTTP_PROXY_HOST      = NULL;
 static char* HTTP_PROXY_PORT      = NULL;
@@ -306,7 +312,7 @@ static char*
 vd_construct_http_query (const char *search_term, VDError *ex)
 {
 	char *query, *encoded_search_term, *pos;
-	int len, i;
+	unsigned len, i;
 
 	/* The worst that can happen is that all chars need encoding */
 	encoded_search_term = 
@@ -318,7 +324,7 @@ vd_construct_http_query (const char *search_term, VDError *ex)
 		return NULL;
 	}
 
-	for (i=0; i<strlen(search_term); i++) 
+	for (i=0; i < strlen(search_term); i++) 
 		if (isalnum(search_term[i])) 
 			*(pos++) = search_term[i];
 		 else 
@@ -335,7 +341,7 @@ vd_construct_http_query (const char *search_term, VDError *ex)
 	}	
 	
 	snprintf (query, len, (HTTP_PROXY_HOST ? HTTP_REQUEST_PROXY : HTTP_REQUEST),
-		  encoded_search_term,encoded_search_term);
+		  encoded_search_term);
 
 	free(encoded_search_term);
 
@@ -356,8 +362,8 @@ vd_get_http_results (int sock, size_t *bytes_read,
 		     VDCallback vd_callback, /*size_t chunk_size*/ /*FIXME*/
 		     VDError *ex)
 {
-	const int max_buf    = 50000;
-	const int chunk_size = 512;
+	const unsigned max_buf    = 50000;
+	const unsigned chunk_size = 512;
 
 	char *buf;
 	int result;
@@ -393,23 +399,19 @@ vd_get_http_results (int sock, size_t *bytes_read,
 static void
 vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 {
-	const size_t min_length = 100;
-
-	int pos;
+	unsigned pos;
 	
-	static const char* word        = "RESULTAAT";
-	static const char* notfound    = "Geen resultaat.";
-	static const char* staatniet   = "gratis woordenboek";
-	static const char* iframe      = "<iframe";
-	static const char *href        = "href=";
+	static const char *word        = "<div class=\"pnn4web_b\"";
+	static const char *notfound    = "of het staat niet";
+	static const char *iframe      = "<div class=\"query\">";
 
 	assert (http_buffer);
 	assert (ex);
 	
 	pos = buffer_find (http_buffer, word, strlen(word));
 
-	if (pos <  buffer_end (http_buffer)) {
-		buffer_erase (http_buffer, 0, pos + strlen(word));
+	if (pos < buffer_end (http_buffer)) {
+		buffer_erase (http_buffer, 0, pos);
 	} else {
 		/* nothing was found or not available*/
 		pos = buffer_find (http_buffer, notfound, strlen(notfound));
@@ -420,12 +422,12 @@ vd_filter_http_buffer (Buffer *http_buffer, VDError* ex)
 		return;
 	}
 
-	/* remove everything in lines with 'staat niet in het gratis woordenboek'
-	 *   until the end; ie. grep -v 'staat niet in gratis woordenboek
+	/* remove everything in lines with /notfound/
+	 *   until the end;
 	 */
 	pos = buffer_find (http_buffer, iframe, strlen(iframe));
-	if (pos <  buffer_end(http_buffer)) {
-		int sol = pos;
+	if (pos < buffer_end(http_buffer)) {
+		unsigned sol = pos;
 		while (sol > buffer_begin(http_buffer) && buffer_at(http_buffer, sol) != '\n')
 			--sol;
 		buffer_erase (http_buffer, sol, buffer_end(http_buffer) - sol);
